==> core-components-file-upload-item-6.2.1.tgz: package/esm/components/content/components/content-subtitle/content-subtitle.js <==
import React, { useContext } from 'react';
import cn from 'classnames';
import { Text } from '@alfalab/core-components-typography/esm';
import { MAX_PROGRESS_BAR_VALUE } from '../../../../const/progress-bar.js';
import { FileUploadItemContext } from '../../../../context/file-upload-item-context.js';
import { isErrorStatus, isUploadingStatus, humanFileSize, isSuccessStatus, isUploadedStatus } from '../../../../utils.js';
import { isError } from '../../utils/isError.js';
import { ContentError } from '../content-error/content-error.js';

var styles = {"subtitle":"file-upload-item__subtitle_1mbv1","truncate":"file-upload-item__truncate_1mbv1","size":"file-upload-item__size_1mbv1"};
require('./content-subtitle.css')

var ContentSubtitle = function () {
    var _a;
    var _b = useContext(FileUploadItemContext), uploadStatus = _b.uploadStatus, subtitle = _b.subtitle, uploadDate = _b.uploadDate, size = _b.size, truncate = _b.truncate, showRestore = _b.showRestore, error = _b.error, progressBar = _b.progressBar;
    var shouldShownError = isErrorStatus(uploadStatus) || isError(error);
    var showMeta = !showRestore && (isSuccessStatus(uploadStatus) || isUploadedStatus(uploadStatus));
    // валидация progressBar (не должен превышать 100 и быть меньше 0)
    var validateProgressBarValue = function (progressValue) {
        if (progressValue === undefined) {
            return 0;
        }
        return Math.min(Math.max(progressValue, 0), MAX_PROGRESS_BAR_VALUE);
    };
    var validProgressBar = validateProgressBarValue(progressBar);
    // uploading status
    if (isUploadingStatus(uploadStatus)) {
        return (React.createElement(Text, { view: 'primary-small', color: 'secondary' },
            "\u0417\u0430\u0433\u0440\u0443\u0437\u043A\u0430",
            '\u00A0',
            Math.floor(validProgressBar),
            "%"));
    }
    // error status
    if (shouldShownError) {
        return React.createElement(ContentError, null);
    }
    // success status
    if (showMeta) {
        return (React.createElement("div", null,
            size && (React.createElement(Text, { className: styles.size, view: 'primary-small', color: 'secondary' }, humanFileSize(size))),
            uploadDate && (React.createElement(Text, { view: 'primary-small', color: 'secondary' }, uploadDate))));
    }
    // restore status
    if (showRestore) {
        return (React.createElement(Text, { view: 'primary-small', color: 'tertiary' }, "\u0424\u0430\u0439\u043B \u0443\u0434\u0430\u043B\u0435\u043D"));
    }
    return (React.createElement(Text, { className: cn(styles.subtitle, (_a = {},
            _a[styles.truncate] = truncate,
            _a)), view: 'primary-small', color: 'secondary' }, subtitle));
};

export { ContentSubtitle };

==> core-components-file-upload-item-6.2.2.tgz: package/esm/components/content/components/content-subtitle/content-subtitle.js <==
import React, { useContext } from 'react';
import cn from 'classnames';
import { Text } from '@alfalab/core-components-typography/esm';
import { MAX_PROGRESS_BAR_VALUE } from '../../../../const/progress-bar.js';
import { FileUploadItemContext } from '../../../../context/file-upload-item-context.js';
import { isErrorStatus, isUploadingStatus, humanFileSize, isSuccessStatus, isUploadedStatus } from '../../../../utils.js';
import { isError } from '../../utils/isError.js';
import { ContentError } from '../content-error/content-error.js';

var styles = {"subtitle":"file-upload-item__subtitle_1glb8","truncate":"file-upload-item__truncate_1glb8","size":"file-upload-item__size_1glb8"};
require('./content-subtitle.css')

var ContentSubtitle = function () {
    var _a;
    var _b = useContext(FileUploadItemContext), uploadStatus = _b.uploadStatus, subtitle = _b.subtitle, uploadDate = _b.uploadDate, size = _b.size, truncate = _b.truncate, showRestore = _b.showRestore, error = _b.error, progressBar = _b.progressBar;
    var shouldShownError = isErrorStatus(uploadStatus) || isError(error);
    var showMeta = !showRestore && (isSuccessStatus(uploadStatus) || isUploadedStatus(uploadStatus));
    // валидация progressBar (не должен превышать 100 и быть меньше 0)
    var validateProgressBarValue = function (progressValue) {
        if (progressValue === undefined) {
            return 0;
        }
        return Math.min(Math.max(progressValue, 0), MAX_PROGRESS_BAR_VALUE);
    };
    var validProgressBar = validateProgressBarValue(progressBar);
    // uploading status
    if (isUploadingStatus(uploadStatus)) {
        return (React.createElement(Text, { view: 'primary-small', color: 'secondary' },
            "\u0417\u0430\u0433\u0440\u0443\u0437\u043A\u0430",
            '\u00A0',
            Math.floor(validProgressBar),
            "%"));
    }
    // error status
    if (shouldShownError) {
        return React.createElement(ContentError, null);
    }
    // success status
    if (showMeta) {
        return (React.createElement("div", null,
            size && (React.createElement(Text, { className: styles.size, view: 'primary-small', color: 'secondary' }, humanFileSize(size))),
            uploadDate && (React.createElement(Text, { view: 'primary-small', color: 'secondary' }, uploadDate))));
    }
    // restore status
    if (showRestore) {
        return (React.createElement(Text, { view: 'primary-small', color: 'tertiary' }, "\u0424\u0430\u0439\u043B \u0443\u0434\u0430\u043B\u0435\u043D"));
    }
    return (React.createElement(Text, { className: cn(styles.subtitle, (_a = {},
            _a[styles.truncate] = truncate,
            _a)), view: 'primary-small', color: 'secondary' }, subtitle));
};

export { ContentSubtitle };
